Class: Fastlane::Helper::BuildCacheHelper
- Inherits:
-
Object
- Object
- Fastlane::Helper::BuildCacheHelper
- Defined in:
- lib/fastlane/plugin/build_cache/helper/build_cache_helper.rb
Class Method Summary collapse
-
.build_identifier ⇒ Object
class methods that you define here become available in your action as
Helper::BuildCacheHelper.your_method. - .ensure_workspace_folder_exists(workspace_path) ⇒ Object
Class Method Details
.build_identifier ⇒ Object
class methods that you define here become available in your action as Helper::BuildCacheHelper.your_method
7 8 9 10 11 |
# File 'lib/fastlane/plugin/build_cache/helper/build_cache_helper.rb', line 7 def self.build_identifier commits = Actions.sh('git rev-list HEAD', log: $verbose).chomp identifier = Digest::SHA256.hexdigest(commits) identifier + '.zip' end |
.ensure_workspace_folder_exists(workspace_path) ⇒ Object
13 14 15 |
# File 'lib/fastlane/plugin/build_cache/helper/build_cache_helper.rb', line 13 def self.ensure_workspace_folder_exists(workspace_path) `mkdir #{workspace_path}` unless File.exist?(workspace_path) end |